@@ -49,7 +49,7 @@ struct _WnckPagerPrivate
   int prelight; /* workspace mouse is hovering over */
   gboolean prelight_dnd; /* is dnd happening? */
 
-  gboolean dragging :1;
+  guint dragging :1;
   int drag_start_x;
   int drag_start_y;
   WnckWindow *drag_window;
@@ -166,7 +166,7 @@ wnck_pager_get_type (void)
   
   if (!object_type)
     {
-      static const GTypeInfo object_info =
+      const GTypeInfo object_info =
       {
         sizeof (WnckPagerClass),
         (GBaseInitFunc) NULL,
@@ -670,10 +670,10 @@ get_window_rect (WnckWindow         *window,
   
   x += wnck_workspace_get_viewport_x (workspace);
   y += wnck_workspace_get_viewport_y (workspace);
-  x *= width_ratio;
-  y *= height_ratio;
-  width *= width_ratio;
-  height *= height_ratio;
+  x = x * width_ratio + 0.5;
+  y = y * height_ratio + 0.5;
+  width = width * width_ratio + 0.5;
+  height = height * height_ratio + 0.5;
   
   x += workspace_rect->x;
   y += workspace_rect->y;
